@@ -1,21 +1,21 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use cosmwasm_std::{to_binary, Binary, CosmosMsg, StdResult, Uint128, WasmMsg};
+use cosmwasm_std::{to_binary, Binary, CosmosMsg, StdResult, WasmMsg};
 
-/// Cw20ReceiveMsg should be de/serialized under `Receive()` variant in a ExecuteMsg
+/// Cw721ReceiveMsg should be de/serialized under `Receive()` variant in a ExecuteMsg
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 #[serde(rename_all = "snake_case")]
-pub struct Cw20ReceiveMsg {
+pub struct Cw721ReceiveMsg {
     pub sender: String,
-    pub amount: Uint128,
-    pub msg: Binary,
+    pub token_id: String,
+    pub msg: Option<Binary>,
 }
 
-impl Cw20ReceiveMsg {
+impl Cw721ReceiveMsg {
     /// serializes the message
     pub fn into_binary(self) -> StdResult<Binary> {
-        let msg = ReceiverExecuteMsg::Receive(self);
+        let msg = ReceiverExecuteMsg::ReceiveNft(self);
         to_binary(&msg)
     }
 
@@ -25,15 +25,16 @@ impl Cw20ReceiveMsg {
         let execute = WasmMsg::Execute {
             contract_addr: contract_addr.into(),
             msg,
-            funds: vec![],
+            send: vec![],
         };
         Ok(execute.into())
     }
 }
 
-// This is just a helper to properly serialize the above message
+/// This is just a helper to properly serialize the above message.
+/// The actual receiver should include this variant in the larger ExecuteMsg enum
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 #[serde(rename_all = "snake_case")]
 enum ReceiverExecuteMsg {
-    Receive(Cw20ReceiveMsg),
+    ReceiveNft(Cw721ReceiveMsg),
 }
